# Minio
Minio is an open source object storage server that is compatible with Amazon S3. You can use it to store and retrieve data from any application that requires s3 storage. You can configure storage tiers and lifecycle policies to manage your data with things like retention and expiration or movements between storage classes.

The use of Minio in this stack is not architected for high availability or data integrity and as such, is not recommended for production use of any reasonably large scale. Instead, this is for making an s3 compatible storage available to the service mesh and ZFS is relied upon for data integrity within a single node storage pool.

For a production ready Minio deployment, please start with the following:
https://min.io/docs/minio/kubernetes/upstream/operations/concepts/architecture.html

## Nomad Job for Minio
Nomad requires a Host Volume to persist data across restarts. This will limit the portability of the running instance but it is simple to configure. If you want have dynamic storage, you will need to modify the job spec to use a different storage driver such as [Ceph](https://docs.ceph.com/en/latest/start/intro/) or [Seaweedfs](https://github.com/seaweedfs/seaweedfs/wiki). Both provide object storage that is S3 compatible so if you deploy those, you may not have a need for Minio but the admin interface and features of Minio may still meet your needs better. 

### Minio-Singleton (minio-singleton.nomad.hcl)
This job is for a single instance of Minio with no tiering. It is the simplest configuration and is suitable for a small amount of data. It is great for getting started with your own S3 compatible storage.

#### Service Dependencies
- A Valid [Host Volume](../../../host_init/README.md#storage-and-zfs)

#### TODO
If you want to deploy this, you will need to verify you have a valid host volume and set the initial  root credentials.

| Line | Default | Adjustment |
| --- | --- | --- |
| 30 | `source = "minio"` | Change `minio` to a valid host volume name if applicable |
| 37 | `volume = "minio-data"` | Change `minio-data` to the host volume defined on line 28 if applicable |
| 54 | `"MINIO_ROOT_USER"="op://InfraSecrets/Minio-Singleton/username"` | Change the value to the root username you want. By default, this is a 1password path. See [Managing Secrets](../../README.md#managing-secrets) for more information |
| 55 | `"MINIO_ROOT_PASSWORD"="op://InfraSecrets/Minio-Singleton/password"` | Change the value to the root password you want. By default, this is a 1password path. See [Managing Secrets](../../README.md#managing-secrets) for more information |

### Minio-Tiered (minio.nomad.hcl)
This job is for an instance of Minio with tiering. If your host has SSDs and HDDs, you can configure Minio to use the SSDs for "HOT" storage and the HDDs for "WARM" storage. This is useful for managing data that is accessed frequently and data that is accessed infrequently. 

> IMPORTANT: Tiering is not a backup solution! You should still have a backup strategy for your data. Best to make backups regularly and follow at least the 3-2-1 rule: 3 copies of your data, 2 on different media, 1 offsite.

#### Service Dependencies
- Two Valid [Host Volumes](../../../host_init/README.md#storage-and-zfs)

#### TODO
If you want to deploy this, you will need to verify you have a valid host volume and set the initial  root credentials.

| Line | Default | Adjustment |
| --- | --- | --- |
| 59 | `source = "minio-ssd"` | Change `minio-ssd` to a valid host volume name if applicable |
| 66 | `volume = "minio-data"` | Change `minio-data` to the host volume defined on line 57 if applicable |
| 83 | `"MINIO_ROOT_USER"="op://InfraSecrets/Minio Tier 1/username"` | Change the value to the root username you want. By default, this is a 1password path. See [Managing Secrets](../../README.md#managing-secrets) for more information |
| 84 | `"MINIO_ROOT_PASSWORD"="op://InfraSecrets/Minio Tier 1/password"` | Change the value to the root password you want. By default, this is a 1password path. See [Managing Secrets](../../README.md#managing-secrets) for more information |
| 113 | `source = "minio-hdd"` | Change `minio-hdd` to a valid host volume name if applicable |
| 121 | `volume = "minio-warm-data"` | Change `minio-warm-data` to the host volume defined on line 111 if applicable |
| 138 | `"MINIO_ROOT_USER"="op://InfraSecrets/Minio Tier 2/username"` | Change the value to the root username you want. By default, this is a 1password path. See [Managing Secrets](../../README.md#managing-secrets) for more information |
| 139 | `"MINIO_ROOT_PASSWORD"="op://InfraSecrets/Minio Tier 2/password"` | Change the value to the root password you want. By default, this is a 1password path. See [Managing Secrets](../../README.md#managing-secrets) for more information |
